package reward

import (
	"github.com/filecoin-project/go-state-types/abi"
	"github.com/filecoin-project/lotus/chain/actors/builtin"
	miner0 "github.com/filecoin-project/specs-actors/actors/builtin/miner"
	"github.com/filecoin-project/specs-actors/actors/builtin/reward"
	"github.com/filecoin-project/specs-actors/actors/util/adt"
	"github.com/filecoin-project/specs-actors/actors/util/smoothing"
)

var _ State = (*state0)(nil)

type state0 struct {
	reward.State
	store adt.Store
}

func (s *state0) ThisEpochReward() (abi.StoragePower, error) {
	return s.State.ThisEpochReward, nil
}

func (s *state0) ThisEpochRewardSmoothed() (builtin.FilterEstimate, error) {
	return builtin.FromV0FilterEstimate(*s.State.ThisEpochRewardSmoothed), nil
}

func (s *state0) ThisEpochBaselinePower() (abi.StoragePower, error) {
	return s.State.ThisEpochBaselinePower, nil
}

func (s *state0) TotalStoragePowerReward() (abi.TokenAmount, error) {
	return s.State.TotalMined, nil
}

func (s *state0) EffectiveBaselinePower() (abi.StoragePower, error) {
	return s.State.EffectiveBaselinePower, nil
}

func (s *state0) EffectiveNetworkTime() (abi.ChainEpoch, error) {
	return s.State.EffectiveNetworkTime, nil
}

func (s *state0) CumsumBaseline() (abi.StoragePower, error) {
	return s.State.CumsumBaseline, nil
}

func (s *state0) CumsumRealized() (abi.StoragePower, error) {
	return s.State.CumsumBaseline, nil
}

func (s *state0) InitialPledgeForPower(sectorWeight abi.StoragePower, networkTotalPledge abi.TokenAmount, networkQAPower *builtin.FilterEstimate, circSupply abi.TokenAmount) (abi.TokenAmount, error) {
	return miner0.InitialPledgeForPower(
		sectorWeight,
		s.State.ThisEpochBaselinePower,
		networkTotalPledge,
		s.State.ThisEpochRewardSmoothed,
		&smoothing.FilterEstimate{
			PositionEstimate: networkQAPower.PositionEstimate,
			VelocityEstimate: networkQAPower.VelocityEstimate,
		},
		circSupply), nil
}

func (s *state0) PreCommitDepositForPower(networkQAPower builtin.FilterEstimate, sectorWeight abi.StoragePower) (abi.TokenAmount, error) {
	return miner0.PreCommitDepositForPower(s.State.ThisEpochRewardSmoothed,
		&smoothing.FilterEstimate{
			PositionEstimate: networkQAPower.PositionEstimate,
			VelocityEstimate: networkQAPower.VelocityEstimate,
		},
		sectorWeight), nil
}
